# How to collaborate with the _earthaccess_ team

## Bi-weekly (alternating weeks) _earthaccess_ hack days

???+ info "How to get invited"

    For an invitation to our recurring hack day meeting, please visit our
    [announcement thread on GitHub Discussions](https://github.com/nsidc/earthaccess/discussions/440#)
    and make a comment to request a calendar invitation and Zoom link.


Hack days...

* Occur on alternating Tuesdays at 11AM - 1PM Mountain Time.
* Are self-determining; you can work on what sounds fun to you!
* Are supportive; _earthaccess_ developers, maintainers, and community managers will
  be present on the call. We welcome and aim to foster new contributions and community members.
* Include live demos on request!

For a glimpse in to the work we do on a typical hack day, please visit our
[hack day share-out space in GitHub Discussions](https://github.com/nsidc/earthaccess/discussions/categories/hack-days)!
